@@ -800,7 +800,7 @@ import numpy as np
 import numpysane as nps
 
 # setup.py assumes the version is a simple string in '' quotes
-__version__ = '0.25'
+__version__ = '0.26'
 
 # note that 'with' is both a known plot and curve option
 knownPlotOptions = frozenset(('dump', 'ascii', 'log', 'notest', 'wait',
@@ -1147,7 +1147,10 @@ defaults are acceptable, use 'hardcopy' only, otherwise use 'terminal' and
             if self.checkpoint_stuck:
                 self.gnuplotProcess.terminate()
             else:
-                self._printGnuplotPipe( "exit\n" )
+                try:
+                    self._printGnuplotPipe( "exit\n" )
+                except:
+                    pass
 
             try:
                 self.gnuplotProcess.wait()
@@ -1325,7 +1328,11 @@ defaults are acceptable, use 'hardcopy' only, otherwise use 'terminal' and
                 # irrelevant inefficiency
                 byte = self.gnuplotProcess.stderr.read(1).decode()
                 fromerr += byte
-                self._logEvent("Read byte '{}' ({}) from gnuplot child process".format(byte, hex(ord(byte))))
+                if byte is not None and len(byte):
+                    self._logEvent("Read byte '{}' ({}) from gnuplot child process".format(byte,
+                                                                                           hex(ord(byte))))
+                else:
+                    self._logEvent("read() returned no data")
             else:
                 self._logEvent("Gnuplot read timed out")
                 self.checkpoint_stuck = True
